@@ -198,24 +198,6 @@ plugin_list_changed_cb (PeasEngine               *engine,
 
   peas_gtk_plugin_manager_store_reload (view->priv->store);
 
-  if (info == NULL)
-    {
-      GtkTreeModel *model;
-      GtkTreeIter iter;
-
-      model = gtk_tree_view_get_model (GTK_TREE_VIEW (view));
-
-      if (gtk_tree_model_get_iter_first (model, &iter))
-        {
-          PeasGtkPluginManagerStore *store;
-
-          store = PEAS_GTK_PLUGIN_MANAGER_STORE (view->priv->store);
-
-          convert_iter_to_child_iter (view, &iter);
-          info = peas_gtk_plugin_manager_store_get_plugin (store, &iter);
-        }
-    }
-
   if (info != NULL)
     peas_gtk_plugin_manager_view_set_selected_plugin (view, info);
 }
@@ -267,6 +249,7 @@ name_search_cb (GtkTreeModel             *model,
                 GtkTreeIter              *iter,
                 PeasGtkPluginManagerView *view)
 {
+  GtkTreeIter child_iter = *iter;
   PeasPluginInfo *info;
   gchar *normalized_string;
   gchar *normalized_key;
@@ -275,7 +258,8 @@ name_search_cb (GtkTreeModel             *model,
   gint key_len;
   gboolean retval;
 
-  info = peas_gtk_plugin_manager_store_get_plugin (view->priv->store, iter);
+  convert_iter_to_child_iter (view, &child_iter);
+  info = peas_gtk_plugin_manager_store_get_plugin (view->priv->store, &child_iter);
 
   if (info == NULL)
     return FALSE;
@@ -449,7 +433,7 @@ menu_position_under_tree_view (GtkMenu     *menu,
   *push_in = TRUE;
 }
 
-static void
+static gboolean
 show_popup_menu (GtkTreeView              *tree_view,
                  PeasGtkPluginManagerView *view,
                  GdkEventButton           *event)
@@ -460,7 +444,7 @@ show_popup_menu (GtkTreeView              *tree_view,
   view->priv->popup_menu = create_popup_menu (view);
 
   if (view->priv->popup_menu == NULL)
-    return;
+    return FALSE;
 
   gtk_menu_attach_to_widget (GTK_MENU (view->priv->popup_menu),
                              GTK_WIDGET (view),
@@ -480,6 +464,8 @@ show_popup_menu (GtkTreeView              *tree_view,
       gtk_menu_shell_select_first (GTK_MENU_SHELL (view->priv->popup_menu),
                                    FALSE);
     }
+
+  return TRUE;
 }
 
 static void
@@ -517,6 +503,8 @@ peas_gtk_plugin_manager_view_init (PeasGtkPluginManagerView *view)
                                             PEAS_GTK_TYPE_PLUGIN_MANAGER_VIEW,
                                             PeasGtkPluginManagerViewPrivate);
 
+  gtk_widget_set_has_tooltip (GTK_WIDGET (view), TRUE);
+
   gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (view), FALSE);
 
@@ -589,19 +577,15 @@ peas_gtk_plugin_manager_view_button_press_event (GtkWidget      *tree_view,
   if (event->type != GDK_BUTTON_PRESS || event->button != 3 || !handled)
     return handled;
 
-  show_popup_menu (GTK_TREE_VIEW (tree_view), view, event);
-
-  return TRUE;
+  return show_popup_menu (GTK_TREE_VIEW (tree_view), view, event);
 }
 
 static gboolean
-peas_gtk_plugin_manager_view_popup_menu (GtkWidget *widget)
+peas_gtk_plugin_manager_view_popup_menu (GtkWidget *tree_view)
 {
-  GtkTreeView *tree_view = GTK_TREE_VIEW (widget);
+  PeasGtkPluginManagerView *view = PEAS_GTK_PLUGIN_MANAGER_VIEW (tree_view);
 
-  show_popup_menu (tree_view, PEAS_GTK_PLUGIN_MANAGER_VIEW (tree_view), NULL);
-
-  return TRUE;
+  return show_popup_menu (GTK_TREE_VIEW (tree_view), view, NULL);
 }
 
 static gboolean
@@ -632,10 +616,10 @@ peas_gtk_plugin_manager_view_query_tooltip (GtkWidget  *widget,
     {
       gchar *message;
 
-      message = g_strdup_printf (_("<b>The plugin '%s' could not be loaded</b>\n"
-                                   "An error occurred: %s"),
-                                 peas_plugin_info_get_name (info),
-                                 error->message);
+      message = g_markup_printf_escaped (_("<b>The plugin '%s' could not be "
+                                           "loaded</b>\nAn error occurred: %s"),
+                                         peas_plugin_info_get_name (info),
+                                         error->message);
 
       gtk_tooltip_set_markup (tooltip, message);
 
@@ -869,6 +853,7 @@ void
 peas_gtk_plugin_manager_view_set_show_builtin (PeasGtkPluginManagerView *view,
                                                gboolean                  show_builtin)
 {
+  GtkTreeSelection *selection;
   GtkTreeIter iter;
   gboolean iter_set;
 
@@ -879,9 +864,14 @@ peas_gtk_plugin_manager_view_set_show_builtin (PeasGtkPluginManagerView *view,
   if (view->priv->show_builtin == show_builtin)
     return;
 
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
+
   /* We must get the selected iter before setting if builtin
      plugins should be shown so the proper model is set */
-  iter_set = peas_gtk_plugin_manager_view_get_selected_iter (view, &iter);
+  iter_set = gtk_tree_selection_get_selected (selection, NULL, &iter);
+
+  if (iter_set)
+    convert_iter_to_child_iter (view, &iter);
 
   view->priv->show_builtin = show_builtin;
 
@@ -905,8 +895,8 @@ peas_gtk_plugin_manager_view_set_show_builtin (PeasGtkPluginManagerView *view,
       g_object_unref (model);
     }
 
-  if (iter_set)
-    peas_gtk_plugin_manager_view_set_selected_iter (view, &iter);
+  if (iter_set && convert_child_iter_to_iter (view, &iter))
+    gtk_tree_selection_select_iter (selection, &iter);
 
   g_object_notify (G_OBJECT (view), "show-builtin");
 }
@@ -927,57 +917,6 @@ peas_gtk_plugin_manager_view_get_show_builtin (PeasGtkPluginManagerView *view)
   return view->priv->show_builtin;
 }
 
-/**
- * peas_gtk_plugin_manager_view_set_selected_iter:
- * @view: A #PeasGtkPluginManagerView.
- * @iter: A #GtkTreeIter.
- *
- * Selects @iter.
- */
-void
-peas_gtk_plugin_manager_view_set_selected_iter (PeasGtkPluginManagerView *view,
-                                                GtkTreeIter              *iter)
-{
-  GtkTreeSelection *selection;
-
-  g_return_if_fail (PEAS_GTK_IS_PLUGIN_MANAGER_VIEW (view));
-  g_return_if_fail (iter != NULL);
-
-  if (!convert_child_iter_to_iter (view, iter))
-    return;
-
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
-  gtk_tree_selection_select_iter (selection, iter);
-}
-
-/**
- * peas_gtk_plugin_manager_view_get_selected_iter:
- * @view: A #PeasGtkPluginManagerView.
- * @iter: A #GtkTreeIter.
- *
- * Returns if @iter was set to the selected plugin.
- *
- * Returns: if @iter was set.
- */
-gboolean
-peas_gtk_plugin_manager_view_get_selected_iter (PeasGtkPluginManagerView *view,
-                                                GtkTreeIter              *iter)
-{
-  GtkTreeSelection *selection;
-
-  g_return_val_if_fail (PEAS_GTK_IS_PLUGIN_MANAGER_VIEW (view), FALSE);
-  g_return_val_if_fail (iter != NULL, FALSE);
-
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
-
-  if (!gtk_tree_selection_get_selected (selection, NULL, iter))
-    return FALSE;
-
-  convert_iter_to_child_iter (view, iter);
-
-  return TRUE;
-}
-
 /**
  * peas_gtk_plugin_manager_view_set_selected_plugin:
  * @view: A #PeasGtkPluginManagerView.
@@ -1016,13 +955,19 @@ peas_gtk_plugin_manager_view_set_selected_plugin (PeasGtkPluginManagerView *view
 PeasPluginInfo *
 peas_gtk_plugin_manager_view_get_selected_plugin (PeasGtkPluginManagerView *view)
 {
+  GtkTreeSelection *selection;
   GtkTreeIter iter;
   PeasPluginInfo *info = NULL;
 
   g_return_val_if_fail (PEAS_GTK_IS_PLUGIN_MANAGER_VIEW (view), NULL);
 
-  if (peas_gtk_plugin_manager_view_get_selected_iter (view, &iter))
-    info = peas_gtk_plugin_manager_store_get_plugin (view->priv->store, &iter);
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
+
+  if (gtk_tree_selection_get_selected (selection, NULL, &iter))
+    {
+      convert_iter_to_child_iter (view, &iter);
+      info = peas_gtk_plugin_manager_store_get_plugin (view->priv->store, &iter);
+    }
 
   return info;
 }
