@@ -72,6 +72,7 @@ gboolean      peas_plugin_info_is_loaded        (const PeasPluginInfo *info);
 gboolean      peas_plugin_info_is_available     (const PeasPluginInfo *info,
                                                  GError               **error);
 gboolean      peas_plugin_info_is_builtin       (const PeasPluginInfo *info);
+gboolean      peas_plugin_info_is_hidden        (const PeasPluginInfo *info);
 
 const gchar  *peas_plugin_info_get_module_name  (const PeasPluginInfo *info);
 const gchar  *peas_plugin_info_get_module_dir   (const PeasPluginInfo *info);
@@ -89,8 +90,6 @@ const gchar  *peas_plugin_info_get_copyright    (const PeasPluginInfo *info);
 const gchar  *peas_plugin_info_get_version      (const PeasPluginInfo *info);
 const gchar  *peas_plugin_info_get_help_uri     (const PeasPluginInfo *info);
 
-gint          peas_plugin_info_get_iage         (const PeasPluginInfo *info);
-
 G_END_DECLS
 
 #endif /* __PEAS_PLUGIN_INFO_H__ */
