@@ -217,7 +217,7 @@ peas_plugin_loader_python_load (PeasPluginLoader *loader,
     {
       g_warning ("Cannot load Python plugin '%s' since libpeas was "
                  "not able to initialize the Python interpreter",
-                 peas_plugin_info_get_name (info));
+                 peas_plugin_info_get_module_name (info));
 
       return FALSE;
     }
@@ -323,11 +323,14 @@ peas_python_shutdown (PeasPluginLoaderPython *loader)
       loader->priv->idle_gc = 0;
     }
 
-  run_gc_protected ();
+  if (!loader->priv->init_failed)
+    run_gc_protected ();
 
   if (loader->priv->must_finalize_python)
     {
-      pyg_gil_state_ensure ();
+      if (!loader->priv->init_failed)
+        pyg_gil_state_ensure ();
+
       Py_Finalize ();
     }
 }
