@@ -89,21 +89,19 @@ peas_plugin_loader_seed_load (PeasPluginLoader *loader,
       seed_context_unref (context);
       return FALSE;
     }
-  else
+
+  global = seed_context_get_global_object (context);
+  extensions = seed_object_get_property (context, global, "extensions");
+
+  if (seed_value_is_object (context, extensions))
     {
-      global = seed_context_get_global_object (context);
-      extensions = seed_object_get_property (context, global, "extensions");
+      sinfo = (SeedInfo *) g_slice_new (SeedInfo);
+      sinfo->context = context;
+      sinfo->extensions = extensions;
+      seed_context_ref (context);
+      seed_value_protect (context, extensions);
 
-      if (seed_value_is_object (context, extensions))
-        {
-          sinfo = (SeedInfo *) g_slice_new (SeedInfo);
-          sinfo->context = context;
-          sinfo->extensions = extensions;
-          seed_context_ref (context);
-          seed_value_protect (context, extensions);
-
-          g_hash_table_insert (sloader->loaded_plugins, info, sinfo);
-        }
+      g_hash_table_insert (sloader->loaded_plugins, info, sinfo);
     }
 
   seed_context_unref (context);
@@ -140,6 +138,8 @@ peas_plugin_loader_seed_create_extension (PeasPluginLoader *loader,
   SeedValue extension_methods, extension;
   gchar **property_names;
   guint i, j;
+  SeedValue value;
+  GValue gvalue = { 0 };
 
   sinfo = (SeedInfo *) g_hash_table_lookup (sloader->loaded_plugins, info);
 
@@ -176,18 +176,21 @@ peas_plugin_loader_seed_create_extension (PeasPluginLoader *loader,
                                 value);
     }
 
-  /* Set the properties as well */
+  /* Set the properties as well, cannot use
+   * g_object_set_property() because it may be construct-only
+   */
   for (i = 0; i < n_parameters; i++)
     {
       gchar *key;
-      SeedValue value;
 
       /* We want to normalize the property names to have a '_' instead of the
        * conventional '-', to make them accessible through this.property_name */
       key = g_strdup (parameters[i].name);
       for (j = 0; key[j] != '\0'; j++)
-        if (key[j] == '-')
-          key[j] = '_';
+        {
+          if (key[j] == '-')
+            key[j] = '_';
+        }
 
       value = seed_value_from_gvalue (sinfo->context,
                                       &parameters[i].value,
@@ -202,6 +205,15 @@ peas_plugin_loader_seed_create_extension (PeasPluginLoader *loader,
 
   g_strfreev (property_names);
 
+  /* Set the plugin info as an attribute of the instance */
+  g_value_init (&gvalue, PEAS_TYPE_PLUGIN_INFO);
+  g_value_set_boxed (&gvalue, info);
+
+  value = seed_value_from_gvalue (sinfo->context, &gvalue, NULL);
+  seed_object_set_property (sinfo->context, extension, "plugin_info", value);
+
+  g_value_unset (&gvalue);
+
   return peas_extension_seed_new (exten_type, sinfo->context, extension);
 }
 
