@@ -27,118 +27,45 @@
 
 #include <glib.h>
 #include <girepository.h>
-
-#include "libpeas/peas-engine-priv.h"
+#include <testing-util.h>
 
 #include "testing.h"
 
-static PeasEngine *engine = NULL;
-static GLogFunc default_log_func;
-
-/* These are warning that just have to happen for testing
- * purposes and as such we don't want to abort on them.
- *
- * Would be nice if we could assert that they were...
- */
-static const gchar *allowed_patterns[] = {
-  "*Plugin not found: does-not-exist*",
-  "*Error while loading icon*does-not-exist*",
-  "*libcloader.so*cannot open shared object file: No such file or directory*",
-};
-
-static void
-log_handler (const gchar    *log_domain,
-             GLogLevelFlags  log_level,
-             const gchar    *message,
-             gpointer        user_data)
+void
+testing_init (void)
 {
-  gint i;
+  GError *error = NULL;
+  static gboolean initialized = FALSE;
 
-  if ((log_level & G_LOG_LEVEL_DEBUG) != 0 ||
-      (log_level & G_LOG_LEVEL_INFO) != 0 ||
-      (log_level & G_LOG_LEVEL_MESSAGE) != 0)
-    {
-      default_log_func (log_domain, log_level, message, user_data);
-      return;
-    }
+  if (initialized)
+    return;
 
-  if ((log_level & G_LOG_LEVEL_CRITICAL) != 0 ||
-      (log_level & G_LOG_LEVEL_ERROR) != 0)
-    {
-      goto out;
-    }
+  testing_util_init ();
 
-  for (i = 0; i < G_N_ELEMENTS (allowed_patterns); ++i)
-    {
-      if (g_pattern_match_simple (allowed_patterns[i], message))
-        return;
-    }
+  g_irepository_prepend_search_path (BUILDDIR "/libpeas-gtk");
 
-out:
+  g_irepository_require (g_irepository_get_default (), "PeasGtk", "1.0", 0, &error);
+  g_assert_no_error (error);
 
-  default_log_func (log_domain, log_level, message, user_data);
-
-  /* Make sure we abort for warnings */
-  abort ();
+  initialized = TRUE;
 }
 
 PeasEngine *
 testing_engine_new (void)
 {
-  GError *error = NULL;
-  static gboolean initialized = FALSE;
+  PeasEngine *engine;
 
-  if (engine != NULL)
-    return engine;
-
-  if (!initialized)
-    {
-      /* Don't always abort on warnings */
-      g_log_set_always_fatal (G_LOG_LEVEL_CRITICAL);
-
-      default_log_func = g_log_set_default_handler (log_handler, NULL);
-
-      g_irepository_prepend_search_path (BUILDDIR "/libpeas");
-      g_irepository_prepend_search_path (BUILDDIR "/libpeas-gtk");
-
-      g_setenv ("PEAS_PLUGIN_LOADERS_DIR", BUILDDIR "/loaders", TRUE);
-
-      g_irepository_require (g_irepository_get_default (), "Peas", "1.0", 0, &error);
-      g_assert_no_error (error);
-      g_irepository_require (g_irepository_get_default (), "PeasGtk", "1.0", 0, &error);
-      g_assert_no_error (error);
-
-      g_atexit (peas_engine_shutdown);
-
-      initialized = TRUE;
-    }
+  testing_init ();
 
   /* Must be after requiring typelibs */
-  engine = peas_engine_new ();
+  engine = testing_util_engine_new ();
 
-  g_object_add_weak_pointer (G_OBJECT (engine), (gpointer *) &engine);
-
-  peas_engine_add_search_path (engine, BUILDDIR "/tests/plugins",
-                                       SRCDIR   "/tests/plugins");
   peas_engine_add_search_path (engine, BUILDDIR "/tests/libpeas-gtk/plugins",
                                        SRCDIR   "/tests/libpeas-gtk/plugins");
 
   return engine;
 }
 
-void
-testing_engine_free (PeasEngine *engine_)
-{
-  /* Incase a test needs to free the engine */
-  if (engine != NULL)
-    {
-      g_object_unref (engine_);
-
-      /* Make sure that at the end of every test the engine is freed */
-      g_assert (engine == NULL);
-    }
-}
-
 PeasPluginInfo *
 testing_get_plugin_info_for_iter (PeasGtkPluginManagerView *view,
                                   GtkTreeIter              *iter)
