@@ -68,7 +68,7 @@ test_engine_new (PeasEngine *engine)
   g_assert (engine != NULL);
   g_assert (new_engine != NULL);
 
-  /* Does not return the same engine*/
+  /* Does not return the same engine */
   g_assert (engine != new_engine);
   /* peas_engine_new() sets the default engine */
   g_assert (engine == peas_engine_get_default ());
@@ -91,15 +91,8 @@ test_engine_dispose (PeasEngine *engine)
 }
 
 static void
-test_engine_get_default (PeasEngine *engine)
+test_engine_get_default (void)
 {
-  /* testing_engine_new() uses peas_engine_new()
-   * so this makes sure that peas_engine_get_default()
-   * acutally sets the default engine
-   */
-
-  g_object_unref (engine);
-
   g_assert (peas_engine_get_default () == peas_engine_get_default ());
 
   g_object_unref (peas_engine_get_default ());
@@ -151,7 +144,7 @@ test_engine_load_plugin_with_nonexistent_dep (PeasEngine *engine)
   GError *error = NULL;
   PeasPluginInfo *info;
 
-  testing_util_push_log_hook ("Could not find plugin 'does-not-exist' for plugin '*'");
+  testing_util_push_log_hook ("Could not find plugin 'does-not-exist'*");
 
   info = peas_engine_get_plugin_info (engine, "nonexistent-dep");
 
@@ -215,7 +208,7 @@ test_engine_unavailable_plugin (PeasEngine *engine)
 {
   PeasPluginInfo *info;
 
-  testing_util_push_log_hook ("Could not find plugin 'does-not-exist' for plugin '*'");
+  testing_util_push_log_hook ("Could not find plugin 'does-not-exist'*");
 
   info = peas_engine_get_plugin_info (engine, "unavailable");
 
@@ -232,8 +225,8 @@ test_engine_not_loadable_plugin (PeasEngine *engine)
 
   testing_util_push_log_hook ("*libnot-loadable.so: cannot open shared "
                               "object file: No such file or directory");
-  testing_util_push_log_hook ("Could not load plugin module: 'Not loadable'");
-  testing_util_push_log_hook ("Error loading plugin 'Not loadable'");
+  testing_util_push_log_hook ("Could not load plugin module: 'not-loadable'");
+  testing_util_push_log_hook ("Error loading plugin 'not-loadable'");
 
   info = peas_engine_get_plugin_info (engine, "not-loadable");
 
@@ -283,7 +276,7 @@ test_engine_loaded_plugins (PeasEngine *engine)
   gchar **load_plugins;
   gchar **loaded_plugins = NULL;
 
-  testing_util_push_log_hook ("Could not find plugin 'does-not-exist' for plugin '*'");
+  testing_util_push_log_hook ("Could not find plugin 'does-not-exist'*");
 
   g_signal_connect_after (engine,
                           "load-plugin",
@@ -369,9 +362,10 @@ test_engine_nonexistent_loader (PeasEngine *engine)
   GError *error = NULL;
   PeasPluginInfo *info;
 
-  testing_util_push_log_hook ("Could not find loader 'does-not-exist' for plugin '*'");
+  testing_util_push_log_hook ("Could not find loader 'does-not-exist'*");
 
   info = peas_engine_get_plugin_info (engine, "nonexistent-loader");
+  peas_engine_enable_loader (engine, "does-not-exist");
 
   g_assert (!peas_engine_load_plugin (engine, info));
   g_assert (!peas_plugin_info_is_loaded (info));
@@ -383,34 +377,27 @@ test_engine_nonexistent_loader (PeasEngine *engine)
 }
 
 static void
-test_engine_enable_loader (PeasEngine *engine)
+test_engine_disabled_loader (PeasEngine *engine)
 {
   PeasPluginInfo *info;
+  GError *error = NULL;
 
-  /* The extension tests implicitly test enabling a loader
-   * This is only to test that the engine will fail to load
-   * a plugin if it's loader is not enabled.
-   */
-
-  testing_util_push_log_hook ("*Could not find loader 'disabled'*");
-  testing_util_push_log_hook ("*Could not find loader 'invalid'*");
+  testing_util_push_log_hook ("Could not find loader 'disabled'*");
 
   info = peas_engine_get_plugin_info (engine, "disabled-loader");
 
   g_assert (!peas_engine_load_plugin (engine, info));
   g_assert (!peas_plugin_info_is_loaded (info));
-  g_assert (!peas_plugin_info_is_available (info, NULL));
+  g_assert (!peas_plugin_info_is_available (info, &error));
+  g_assert_error (error, PEAS_PLUGIN_INFO_ERROR,
+                  PEAS_PLUGIN_INFO_ERROR_LOADER_NOT_FOUND);
 
+  g_error_free (error);
+}
 
-  info = peas_engine_get_plugin_info (engine, "invalid-loader");
-  peas_engine_enable_loader (engine, "invalid");
-
-  g_assert (!peas_engine_load_plugin (engine, info));
-  g_assert (!peas_plugin_info_is_loaded (info));
-  g_assert (!peas_plugin_info_is_available (info, NULL));
-
-
-  /* Make sure loaders can be enabled multiple times */
+static void
+test_engine_enable_loader_multiple_times (PeasEngine *engine)
+{
   peas_engine_enable_loader (engine, "C");
 }
 
@@ -423,15 +410,13 @@ test_engine_nonexistent_search_path (PeasEngine *engine)
 
 
 static void
-test_engine_shutdown (PeasEngine *engine)
+test_engine_shutdown (void)
 {
-  testing_engine_free (engine);
-
   /* Should be able to shutdown multiple times */
   peas_engine_shutdown ();
   peas_engine_shutdown ();
 
-  /* Cannot get the default as libpeas has been shutdown */
+  /* Cannot create an engine because libpeas has been shutdown */
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
     {
       peas_engine_new ();
@@ -455,9 +440,12 @@ main (int    argc,
               (gpointer) test_engine_##ftest, \
               test_setup, test_runner, test_teardown)
 
+#define TEST_FUNC(path, ftest) \
+  g_test_add_func ("/engine/" path, test_engine_##ftest)
+
   TEST ("new", new);
   TEST ("dispose", dispose);
-  TEST ("get-default", get_default);
+  TEST_FUNC ("get-default", get_default);
 
   TEST ("load-plugin", load_plugin);
   TEST ("load-plugin-with-dep", load_plugin_with_dep);
@@ -474,12 +462,13 @@ main (int    argc,
   TEST ("loaded-plugins", loaded_plugins);
 
   TEST ("nonexistent-loader", nonexistent_loader);
-  TEST ("enable-loader", enable_loader);
+  TEST ("disabled-loader", disabled_loader);
+  TEST ("enable-loader-multiple-times", enable_loader_multiple_times);
 
   TEST ("nonexistent-search-path", nonexistent_search_path);
 
   /* MUST be last */
-  TEST ("shutdown", shutdown);
+  TEST_FUNC ("shutdown", shutdown);
 
 #undef TEST
 
